@@ -63,7 +63,13 @@ class RedisExpiryChecker:
     Checker for redis expiry events (stops data worker and allows it to restart automatically)
     """
 
-    def __init__(self, redis=None, shared_memory_manager_dict=None, monitor=None, stop_data_worker_fun=None):
+    def __init__(
+        self,
+        redis=None,
+        shared_memory_manager_dict=None,
+        monitor=None,
+        stop_data_worker_fun=None,
+    ):
         self.redis = redis
         self.shared_memory_manager_dict = shared_memory_manager_dict
         self.redis_pubsub = self.redis.pubsub()
